datadog\_api\_client.v2
=======================

.. toctree::
   :maxdepth: 4

   datadog_api_client.v2.api
   datadog_api_client.v2.model


.. automodule:: datadog_api_client.v2
   :members:
   :show-inheritance:
